---
name: Bug report
about: Create a report to help us improve
title: 'Bug: '
labels: bug
assignees: k98kurz

---

### Describe the bug

A clear and concise description of what the bug is.

### To Reproduce

Steps to reproduce the behavior:
1. ...
2. ...
3. ...

### Expected behavior

A clear and concise description of what you expected to happen.

### Screenshots

If applicable, add screenshots to help explain your problem.

### Platform and Version (please complete the following information)

- Platform/device: [e.g. desktop or specific phone model]
- OS: [e.g. Ubuntu]
- Python Version: [e.g. 3.10]
- Library Version [e.g. 0.1.0]

### Additional context

Add any other context about the problem here.
